@@ -1,6 +1,6 @@
 /*
 
- Copyright (C) 2013-2017 Alexis Bienvenue <paamc@passoire.fr>
+ Copyright (C) 2013-2022 Alexis Bienvenüe <paamc@passoire.fr>
 
  This file is part of Auto-Multiple-Choice
 
@@ -57,7 +57,7 @@ int main(int argc, char** argv )
   g_type_init ();
 #endif
 
-  char ch;
+  int ch;
   while ((ch = getopt(argc, argv, "d:h:w:l:")) != -1) {
     switch(ch) {
     case 'd': dppt = atof(optarg) / 72.0; break;
