@@ -1,6 +1,6 @@
 # -*- perl -*-
 #
-# Copyright (C) 2017-2021 Alexis Bienvenüe <paamc@passoire.fr>
+# Copyright (C) 2017-2022 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -49,9 +49,11 @@ sub new {
         system_encoding => 'UTF-8',
         shortcuts       => '',
         home_dir        => '',
+        global_file     => '',
         empty           => 0,
         gui             => 0,
         testing         => '',
+        read_only       => '',
     };
 
     for my $k ( keys %o ) {
@@ -158,7 +160,8 @@ sub pref_xml_lit {
         my $data = XMLin(
             $file,
             SuppressEmpty => '',
-            ForceArray    => [ 'docs', 'email_attachment', 'printer' ]
+            ForceArray    =>
+              [ 'docs', 'email_attachment', 'printer', 'recent_projects' ]
         );
         return (%$data);
     }
@@ -267,6 +270,7 @@ sub defaults {
         seuil_sens              => 8.0,
         saisie_dpi              => 150,
         vector_scan_density     => 250,
+        pdfimages_opts          => '-png -j',
         force_convert           => '',
         n_procs                 => 0,
         delimiteur_decimal      => ',',
@@ -283,6 +287,7 @@ sub defaults {
         checklayout_window_size => '',
         manual_window_size      => '',
         marks_window_size       => '',
+        strategy_window_size    => '',
         conserve_taille         => 1,
         methode_impression      => 'CUPS',
         imprimante              => '',
@@ -413,6 +418,13 @@ sub defaults {
         view_empty_color   => "#78FFED",
 
         defaut_name_field_type => '',
+
+        view_anonymity   => '',
+        anonymous_model  => 'edddds',
+        anonymous_header => '%(aID)',
+        anonymous_header_allpages => 1,
+
+        recent_projects => [],
     };
 
     $self->{project_default} = {
@@ -520,9 +532,13 @@ sub defaults {
 sub load_profile {
     my ($self) = @_;
 
-    debug "Profile: $self->{profile}";
-    $self->{global_file} = $self->{o_dir} . "/cf." . $self->{profile} . ".xml";
-
+    if ( $self->{global_file} ) {
+        debug "Profile from: $self->{global_file}";
+    } else {
+        debug "Profile: $self->{profile}";
+        $self->{global_file} =
+          $self->{o_dir} . "/cf." . $self->{profile} . ".xml";
+    }
     $self->{global} = { pref_xml_lit( $self->{global_file} ) };
 
     $self->set_global_options_to_default();
@@ -576,7 +592,10 @@ sub set_global_option_to_default {
                     if ( $kind eq 'command' ) {
                         $self->{global}->{$key} =
                           commande_accessible( \@values );
-                        if ( !$self->{global}->{$key} ) {
+                        if ( $self->{global}->{$key} ) {
+                            debug "New global command: $key = "
+                              . $self->{global}->{$key};
+                        } else {
                             debug
 "No available command for option $key: using the first one";
                             $self->{global}->{$key} = $values[0];
@@ -585,21 +604,25 @@ sub set_global_option_to_default {
                         debug "ERR: unknown option kind : $kind";
                     }
                 } else {
+                    debug "New global empty array: $key";
                     $self->{global}->{$key} = [];
                 }
             } elsif ( ref( $self->{o_default}->{$key} ) eq 'HASH' ) {
 
                 # HASH value: copy it
                 $self->{global}->{$key} = { %{ $self->{o_default}->{$key} } };
+
+                debug "New global hash: $key";
             } else {
                 $self->{global}->{$key} = $self->{o_default}->{$key};
 
                 # default value for encoding options:
                 $self->{global}->{$key} = $self->{system_encoding}
                   if ( $key =~ /^encodage_/ && !$self->{global}->{$key} );
+
+                debug "New global parameter: $key = $self->{global}->{$key}"
+                    if ( $self->{global}->{$key} );
             }
-            debug "New global parameter : $key = $self->{global}->{$key}"
-              if ( $self->{global}->{$key} );
         } else {
 
             # already defined option: go with sub-options if any
@@ -730,11 +753,53 @@ sub project_options_file {
     return "$dir/$name/options.xml";
 }
 
+sub add_recent_project {
+    my ( $self, $dir, $name ) = @_;
+
+    # The global option recent_projects should be an array. If not, free it.
+    if ( ref( $self->{global}->{recent_projects} ) ne 'ARRAY' ) {
+        debug "WARNING: global recent_projects is "
+          . $self->{global}->{recent_projects};
+        $self->{global}->{recent_projects} = [];
+    }
+
+    # First remove already existing same entries
+    my $full_dir = $dir . "/" . $name;
+
+    @{ $self->{global}->{recent_projects} } =
+      grep { $_->{dir} . '/' . $_->{project} ne $full_dir }
+      @{ $self->{global}->{recent_projects} };
+
+    # Add entry at beginning
+    unshift @{ $self->{global}->{recent_projects} },
+      { dir => $self->{global}->{rep_projets}, project => $name };
+
+    # Keep only 40 entries
+    splice @{ $self->{global}->{recent_projects} }, 40;
+
+    # Tag global options to be saved
+    $self->{global}->{_changed} = 1;
+}
+
+sub recent_projects_list {
+    my ( $self, $max ) = @_;
+    my @p = grep { -f $self->project_options_file( $_->{project}, $_->{dir} ) }
+      @{ $self->{global}->{recent_projects} };
+    if ($max) {
+        splice @p, $max;
+    }
+    return(@p);
+}
+
 sub open_project {
     my ( $self, $name ) = @_;
+    debug "AMC::Config: open project " . show_utf8($name);
     $self->{project_file} = $self->project_options_file($name);
     $self->{project}      = { pref_xml_lit( $self->{project_file} ) };
 
+    # Adds the project in the recent projects list
+    $self->add_recent_project( $self->{global}->{rep_projets}, $name );
+
     # Get old style working documents names
     if ( ref( $self->{project}->{docs} ) eq 'ARRAY' ) {
         $self->{project}->{doc_question} = $self->{project}->{docs}->[0];
@@ -761,7 +826,8 @@ sub open_project {
     # Convert old style ODS group sum options
     if ( !defined( $self->{project}->{export_ods_group} ) ) {
         $self->{project}->{export_ods_group} =
-          ( $self->{project}->{export_ods_groupsep} eq '' ? 0 : 1 );
+            ( defined($self->{project}->{export_ods_groupsep}) &&
+              $self->{project}->{export_ods_groupsep} ne '' ? 1 : 0 );
         $self->{project}->{export_ods_groupsep} = '.'
           if ( !$self->{project}->{export_ods_groupsep} );
     }
@@ -854,6 +920,89 @@ sub get_absolute {
     return ( $self->{shortcuts}->absolu( $self->get($key) ) );
 }
 
+sub bon_encodage {
+    my ( $self, $type ) = @_;
+    return ( $self->get("encodage_$type")
+          || $self->get("defaut_encodage_$type")
+          || "UTF-8" );
+}
+
+sub csv_build_0 {
+    my ( $self, $k, @default ) = @_;
+    push @default, grep { $_ } map { s/^\s+//; s/\s+$//; $_; }
+      split( /,+/, $self->get( 'csv_' . $k . '_headers' ) );
+    return ( "(" . join( "|", @default ) . ")" );
+}
+
+sub csv_build_name {
+    my ($self) = @_;
+    return ($self->csv_build_0( 'surname', 'nom', 'surname' ) . ' '
+          . $self->csv_build_0( 'name', 'prenom', 'name' ) );
+}
+
+sub moteur_latex {
+    my ($self) = @_;
+    return ( $self->get('moteur_latex_b')
+          || $self->get('defaut_moteur_latex_b') );
+}
+
+sub pdf_password {
+    my ($self) = @_;
+    return (
+          $self->get('pdf_password_use')
+        ? $self->get('pdf_password')
+        : ""
+    );
+}
+
+sub extract_with {
+    my ($self) = @_;
+    my $conf = $self->get('print_extract_with');
+    if ( $self->get('project:pdfform') ) {
+        if ( $conf =~ /^(qpdf|sejda|pdftk\+NA)/ ) {
+            return ($conf);
+        } else {
+            if ( commande_accessible('sejda-console') ) {
+                return ('sejda-console');
+            } elsif ( commande_accessible('qpdf') ) {
+                return ('qpdf');
+            } else {
+                return ('pdftk+NA');
+            }
+        }
+    } else {
+        return ($conf);
+    }
+}
+
+sub opt_symbole {
+    my ( $self, $s ) = @_;
+    my $k = $s;
+
+    $k =~ s/-/_/g;
+    my $type  = $self->get( 'symbole_' . $k . '_type',  'none' );
+    my $color = $self->get( 'symbole_' . $k . '_color', 'red' );
+
+    return ("$s:$type/$color");
+}
+
+sub symbols {
+    my ($self) = @_;
+    return join( ',', map { $self->opt_symbole($_); } (qw/0-0 0-1 1-0 1-1/) );
+}
+
+sub tolerance {
+    my ($self) = @_;
+    return $self->get('tolerance_marque_inf') . ','
+        . $self->get('tolerance_marque_sup');
+}
+
+sub pre_association {
+    my ($self) = @_;
+    return ( $self->get('assoc_code') &&
+             $self->get('assoc_code') eq '<preassoc>' ? 1 : 0 );
+}
+
 sub set {
     my ( $self, $key, $value ) = @_;
     my $k   = $self->parse_key( $key, 'create' );
@@ -961,6 +1110,8 @@ sub list_all_keys {
 sub save {
     my ( $self, $dont_warn ) = @_;
 
+    return () if ( $self->{read_only} );
+
     for my $c (qw/project global state/) {
         if ( $self->{$c}->{_changed} ) {
             my $file = $self->{ $c . "_file" };
