@@ -1,6 +1,4 @@
-#! /usr/bin/perl -w
-#
-# Copyright (C) 2008-2021 Alexis Bienvenüe <paamc@passoire.fr>
+# Copyright (C) 2008-2022 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -206,7 +204,8 @@ sub new {
         invalid_color_name => $self->{invalid_color_name},
         empty_color_name   => $self->{empty_color_name},
         editable           => $self->{editable},
-        marks              => ( $self->{editable} ? '' : 'blue' )
+        marks              => ( $self->{editable} ? '' : 'blue' ),
+        zones              => ( $self->{editable} ? '' : 'lightblue' ),
     );
 
     AMC::Gui::WindowSize::size_monitor( $self->window, $self->{size_monitor} )
@@ -601,7 +600,7 @@ sub charge_i {
 
         debug "Getting layout info";
 
-        for (qw/box questionbox namefield digit scorezone/) {
+        for (qw/box questionbox namefield idzone digit scorezone/) {
             $self->{layinfo}->{$_} = [];
         }
 
@@ -628,7 +627,7 @@ sub charge_i {
             my $c;
             my $sth;
 
-            for my $type (qw/box questionbox scorezone digit namefield/) {
+            for my $type (qw/box questionbox scorezone digit namefield idzone/) {
                 for my $c ( $self->{layout}->type_info( $type, @ep ) ) {
                     push @{ $self->{layinfo}->{$type} }, {%$c};
                 }
