@@ -1,6 +1,6 @@
 # -*- perl -*-
 #
-# Copyright (C) 2012-2021 Alexis Bienvenüe <paamc@passoire.fr>
+# Copyright (C) 2012-2022 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -209,16 +209,16 @@ sub set_variables_from_hashref {
 
 sub defined_variable {
     my ( $self, $vv ) = @_;
-    return ( $self->{variables}->{$vv}->[ $self->{type} ] ? 1 : 0 );
+    return (0) if ( !$self->{variables}->{$vv} );
+    return (0) if ( !$self->{variables}->{$vv}->[ $self->{type} ] );
+    return ( defined( $self->{variables}->{$vv}->[ $self->{type} ] ) );
 }
 
 # get variable value.
 
 sub get_variable {
     my ( $self, $vv ) = @_;
-    if (   $self->{variables}->{$vv}
-        && $self->{variables}->{$vv}->[ $self->{type} ] )
-    {
+    if ( $self->defined_variable($vv) ) {
         return ( $self->{variables}->{$vv}->[ $self->{type} ]->{value} );
     } else {
         return (undef);
@@ -230,12 +230,17 @@ sub get_variable {
 sub parse_defs {
     my ( $self, $string, $plain_only ) = @_;
     my @r = ();
-    for my $def ( quotewords( ',+', 0, $string ) ) {
+    for my $def ( quotewords( ',+', 1, $string ) ) {
         if ( length($def) ) {
+            $def =~ s/^\s*(['"])(.*)\g{1}\s*$/$2/;
             if ( $def =~ /^\s*([.a-zA-Z0-9_-]+)\s*=\s*(.*)/ ) {
-
                 # "variable=value" case
-                push @r, { key => $1, value => $2 } if ( !$plain_only );
+                my $variable = $1;
+                my $value    = $2;
+                $value =~ s/\s+$//;
+                $value =~ s/^(['"])(.*)\g{1}$/$2/;
+                push @r, { key => $variable, value => $value }
+                  if ( !$plain_only );
             } else {
 
                 # "value" case
@@ -381,21 +386,31 @@ sub process_directives {
 sub evaluate {
     my ( $self, $string ) = @_;
 
-    return (undef) if ( !defined($string) );
-    return ('') if ( $string eq '' );
+    if ( !defined($string) ) {
+        debug "Value is undef";
+        return (undef);
+    }
+    if ( $string eq '' ) {
+        debug "Value is empty";
+        return ('');
+    }
 
     my $string_orig = $string;
     for my $vv ( keys %{ $self->{variables} } ) {
         my $value = $self->get_variable($vv);
         if ( defined($value) ) {
-            $string =~ s/\b$vv\b/$value/g;
+            if ( $value eq "" ) {
+                $string =~ s/\b$vv\b/''/g;
+            } else {
+                $string =~ s/\b$vv\b/$value/g;
+            }
         } else {
             $string =~ s/\b$vv\b/undef/g;
         }
     }
     my $calc = eval($string);
-    $self->error("Syntax error (evaluation) : $string")
-      if ( !defined($calc) );
+    $self->error("Syntax error (evaluation of $string): $@")
+      if ($@);
     debug "Evaluation ["
       . printable( $self->{type} ) . "] : "
       . printable($string_orig) . " => "
@@ -425,6 +440,7 @@ sub get_directive {
 
     if ( $self->{directives}->{$key} ) {
         if ( !$self->{directives}->{$key}->{evaluated} ) {
+            debug "Evaluate directive $key";
             $self->{directives}->{$key}->{value} =
               $self->evaluate( $self->{directives}->{$key}->{def} );
             $self->{directives}->{$key}->{evaluated} = 1;
