@@ -1,6 +1,6 @@
-#! /usr/bin/perl -w
+#! /usr/bin/env perl
 #
-# Copyright (C) 2012-2021 Alexis Bienvenüe <paamc@passoire.fr>
+# Copyright (C) 2012-2022 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -49,72 +49,80 @@ use utf8;
 
 use_gettext;
 
+my $defaults = {
+    dir                 => '',
+    filter              => '',
+    tex_engine          => 'pdflatex',
+    multiple            => '',
+    pre_allocate        => 0,
+    n_copies            => 5,
+    check_marks         => '',
+    perfect_copy        => [3],
+    src                 => '',
+    debug               => 0,
+    debug_pixels        => 0,
+    scans               => '',
+    seuil               => 0.5,
+    seuil_up            => 1.0,
+    bw_threshold        => 0.6,
+    ignore_red          => '',
+    tol_marque          => 0.4,
+    rounding            => 'i',
+    grain               => 0.01,
+    notemax             => 20,
+    postcorrect_student => '',
+    postcorrect_copy    => '',
+    list                => '',
+    list_key            => 'id',
+    code                => 'student',
+    check_assoc         => '',
+    association_manual  => '',
+    annote              => '',
+    annote_files        => [],
+    annote_ascii        => 0,
+    annote_position     => 'marge',
+    annotate_single     => '',
+    verdict             => '%(id) %(ID)' . "\n" . 'TOTAL : %S/%M => %s/%m',
+    verdict_question    => "\"%" . "s/%" . "m\"",
+    model               => '(N).pdf',
+    ok_checksums        => {},
+    ok_checksums_file   => '',
+    to_check            => [],
+    export_full_csv     => [],
+    export_columns      => 'student.copy',
+    export_csv_ticked   => 'AB',
+    export_csv_decimal  => ',',
+    export_ods          => '',
+    blind               => 0,
+    check_zooms         => {},
+    check_subject       => '',
+    skip_prepare        => 0,
+    skip_scans          => 0,
+    tracedest           => \*STDERR,
+    debug_file          => '',
+    pages               => '',
+    extract_with        => 'qpdf',
+    force_convert       => 0,
+    force_magick        => 0,
+    no_gs               => 0,
+    documents           => 'sc',
+    speed               => 0,
+    full_scans          => '',
+    full_density        => 300,
+    tmpdir              => '',
+    decoder             => '',
+    password            => '',
+    password_key        => 'password',
+    setup               => 1,
+    exitonerror         => 1,
+    postinstall         => '',
+    additional_test     => '',
+};
+
 sub new {
     my ( $class, %oo ) = @_;
 
-    my $self = {
-        dir                 => '',
-        filter              => '',
-        tex_engine          => 'pdflatex',
-        multiple            => '',
-        pre_allocate        => 0,
-        n_copies            => 5,
-        check_marks         => '',
-        perfect_copy        => [3],
-        src                 => '',
-        debug               => 0,
-        debug_pixels        => 0,
-        scans               => '',
-        seuil               => 0.5,
-        seuil_up            => 1.0,
-        bw_threshold        => 0.6,
-        ignore_red          => '',
-        tol_marque          => 0.4,
-        rounding            => 'i',
-        grain               => 0.01,
-        notemax             => 20,
-        postcorrect_student => '',
-        postcorrect_copy    => '',
-        list                => '',
-        list_key            => 'id',
-        code                => 'student',
-        check_assoc         => '',
-        association_manual  => '',
-        annote              => '',
-        annote_files        => [],
-        annote_ascii        => 0,
-        annote_position     => 'marge',
-        verdict             => '%(id) %(ID)' . "\n" . 'TOTAL : %S/%M => %s/%m',
-        verdict_question    => "\"%" . "s/%" . "m\"",
-        model               => '(N).pdf',
-        ok_checksums        => {},
-        ok_checksums_file   => '',
-        to_check            => [],
-        export_full_csv     => [],
-        export_columns      => 'student.copy',
-        export_csv_ticked   => 'AB',
-        export_ods          => '',
-        blind               => 0,
-        check_zooms         => {},
-        check_subject       => '',
-        skip_prepare        => 0,
-        skip_scans          => 0,
-        tracedest           => \*STDERR,
-        debug_file          => '',
-        pages               => '',
-        extract_with        => 'qpdf',
-        force_convert       => 0,
-        force_magick        => 0,
-        no_gs               => 0,
-        documents           => 'sc',
-        speed               => 0,
-        full_scans          => '',
-        full_density        => 300,
-        tmpdir              => '',
-        decoder             => '',
-        password            => '',
-        password_key        => 'password',
-    };
+    my $self = { error=>0, %$defaults };
 
     for ( keys %oo ) {
         $self->{$_} = $oo{$_} if ( exists( $self->{$_} ) );
@@ -124,6 +132,36 @@ sub new {
 
     bless( $self, $class );
 
+    my $to_stdout = 0;
+
+    GetOptions(
+        "debug!"         => \$self->{debug},
+        "blind!"         => \$self->{blind},
+        "log-to=s"       => \$self->{debug_file},
+        "to-stdout!"     => \$to_stdout,
+        "extract-with=s" => \$self->{extract_with},
+        "tmp=s"          => \$self->{tmpdir},
+    );
+
+    $self->{tmpdir} = tmpdir() if ( !$self->{tmpdir} );
+
+    $self->{tracedest} = \*STDOUT if ($to_stdout);
+    binmode $self->{tracedest}, ":utf8";
+
+    $self->setup() if($self->{setup});
+
+    return $self;
+}
+
+sub clean {
+    my ($self) = @_;
+
+    $self->set( src => '', scans => '', names => '', list => '' );
+}
+
+sub setup {
+    my ($self)=@_;
+
     if ( !$self->{src} ) {
         opendir( my $dh, $self->{dir} )
           || die "can't opendir $self->{dir}: $!";
@@ -143,21 +181,6 @@ sub new {
       AMC::NamesFile::new( $self->{dir} . '/' . $self->{list}, 'utf8', 'id' )
       if ( $self->{list} && -f $self->{dir} . '/' . $self->{list} );
 
-    my $to_stdout = 0;
-
-    GetOptions(
-        "debug!"         => \$self->{debug},
-        "blind!"         => \$self->{blind},
-        "log-to=s"       => \$self->{debug_file},
-        "to-stdout!"     => \$to_stdout,
-        "extract-with=s" => \$self->{extract_with},
-        "tmp=s"          => \$self->{tmpdir},
-    );
-
-    $self->{tmpdir} = tmpdir() if ( !$self->{tmpdir} );
-
-    $self->{tracedest} = \*STDOUT if ($to_stdout);
-    binmode $self->{tracedest}, ":utf8";
 
     $self->install;
 
@@ -168,8 +191,6 @@ sub new {
     $self->read_checksums( $self->{dir} . '/ok-checksums' );
 
     require Time::HiRes if ( $self->{speed} );
-
-    return $self;
 }
 
 sub set {
@@ -182,6 +203,12 @@ sub set {
     return $self;
 }
 
+sub failed {
+    my ( $self, $error ) = @_;
+    $self->{error} += $error;
+    exit($error) if ( $self->{exitonerror} );
+}
+
 sub read_checksums {
     my ( $self, $file ) = @_;
 
@@ -245,6 +272,10 @@ sub install {
     print DB "Test\n";
     close(DB);
 
+    if ( $self->{postinstall} ) {
+        &{ $self->{postinstall} }($self);
+    }
+
     return $self;
 }
 
@@ -303,12 +334,14 @@ sub see_file {
         return ();
     }
 
-    # compares with already validated file
-    my $validated = $self->{temp_dir} . "/checked/$ff";
-    if ( -f $validated && $ff =~ /\.pdf$/i ) {
-        if ( run( 'comparepdf', '-ca', '-v0', $validated, $file ) ) {
-            $self->trace("[T] File ok (compare): $ff");
-            return ();
+    if ( commande_accessible('comparepdf') ) {
+        # compares with already validated file
+        my $validated = $self->{temp_dir} . "/checked/$ff";
+        if ( -f $validated && $ff =~ /\.pdf$/i ) {
+            if ( run( 'comparepdf', '-ca', '-v0', $validated, $file ) ) {
+                $self->trace("[T] File ok (compare): $ff");
+                return ();
+            }
         }
     }
 
@@ -342,7 +375,7 @@ sub command {
         $cc .= " " . $c[1] if ( $#c > 0 );
         $cc .= " ..."      if ( $#c > 1 );
         $self->trace("[E] Command `$cc' returned with $?");
-        exit 1;
+        $self->failed(1);
     }
 }
 
@@ -390,11 +423,11 @@ sub prepare {
 }
 
 sub analyse {
-    my ($self) = @_;
+    my ($self, %oo) = @_;
 
     $self->start_clock();
 
-    if ( $self->{perfect_copy} || $self->{full_scans} ) {
+    if ( ($self->{perfect_copy} || $self->{full_scans}) && !$oo{directory} ) {
         $self->amc_command(
             'prepare',           '--filter',
             $self->{filter},     '--with',
@@ -406,7 +439,7 @@ sub analyse {
         );
     }
 
-    if ( $self->{perfect_copy} ) {
+    if ( $self->{perfect_copy} && !$oo{directory} ) {
         my $nf = $self->{temp_dir} . "/num";
         open( NUMS, ">$nf" );
         for ( @{ $self->{perfect_copy} } ) { print NUMS "$_\n"; }
@@ -432,7 +465,7 @@ sub analyse {
         push @{ $self->{scans} }, map { $self->{temp_dir} . "/$_" } @s;
     }
 
-    if ( $self->{full_scans} ) {
+    if ( $self->{full_scans} && !$oo{directory} ) {
         my @cmd = (
             "gs",
             "-sDEVICE=png16m",
@@ -478,7 +511,23 @@ sub analyse {
 
     my $scans_list = $self->{temp_dir} . "/scans-list.txt";
     open( SL, ">", $scans_list ) or die "Open $scans_list: $!";
-    for ( @{ $self->{scans} } ) { print SL "$_\n"; }
+    if ( $oo{directory} ) {
+        opendir( my $dh, $self->{temp_dir} . "/" . $oo{directory} )
+          || die "can't opendir $oo{directory}: $!";
+        my @s = sort { $a cmp $b } grep { !/^\./ } readdir($dh);
+        closedir $dh;
+
+        if (@s) {
+            $self->trace( "[I] " . @s . " scans from $oo{directory}" );
+            for my $f (@s) {
+                print SL $self->{temp_dir} . "/"
+                  . $oo{directory} . "/"
+                  . $f . "\n";
+            }
+        }
+    } else {
+        for ( @{ $self->{scans} } ) { print SL "$_\n"; }
+    }
     close(SL);
 
     #
@@ -517,6 +566,9 @@ sub analyse {
         @extract_opts,
     );
 
+    $self->{pre_allocate} = $oo{pre_allocate}
+      if ( exists( $oo{pre_allocate} ) );
+
     $self->amc_command(
         'analyse',
         ( $self->{multiple} ? '--multiple' : '--no-multiple' ),
@@ -560,6 +612,13 @@ sub analyse {
 
 }
 
+sub gather_multicode {
+    my ($self)=@_;
+
+    $self->note( multi => 1 );
+    $self->amc_command( 'gathermulticode', '--project', '%PROJ', );
+}
+
 sub decode {
     my ($self) = @_;
 
@@ -571,18 +630,27 @@ sub decode {
 }
 
 sub note {
-    my ($self) = @_;
+    my ($self, %oo) = @_;
 
     $self->start_clock();
     $self->amc_command(
-        'note',                       '--data',
-        '%DATA',                      '--seuil',
-        $self->{seuil},               '--seuil-up',
-        $self->{seuil_up},            '--grain',
-        $self->{grain},               '--arrondi',
-        $self->{rounding},            '--notemax',
-        $self->{notemax},             '--postcorrect-student',
-        $self->{postcorrect_student}, '--postcorrect-copy',
+        'note',
+        ( $oo{multi} ? "--multi-only" : "--no-multi-only" ),
+        '--data',
+        '%DATA',
+        '--seuil',
+        $self->{seuil},
+        '--seuil-up',
+        $self->{seuil_up},
+        '--grain',
+        $self->{grain},
+        '--arrondi',
+        $self->{rounding},
+        '--notemax',
+        $self->{notemax},
+        '--postcorrect-student',
+        $self->{postcorrect_student},
+        '--postcorrect-copy',
         $self->{postcorrect_copy},
     );
     $self->stop_clock("scoring");
@@ -636,6 +704,8 @@ sub get_marks {
             );
         }
     }
+
+    $dbh->disconnect;
 }
 
 sub get_orientation {
@@ -645,6 +715,9 @@ sub get_orientation {
     $l->begin_read_transaction('tgor');
     my $o = $l->orientation();
     $l->end_transaction('tgor');
+
+    $l->disconnect;
+
     return ($o);
 }
 
@@ -672,7 +745,7 @@ sub check_perfect {
     for my $i ( keys %p ) {
         if ( $p{$i} ) {
             $self->trace("[E] Non-perfect copy: $i");
-            exit(1);
+            $self->failed(1);
         }
     }
 }
@@ -703,7 +776,7 @@ sub check_marks {
     my @no = ( keys %p );
     if (@no) {
         $self->trace( "[E] Uncorrect marks: " . join( ',', @no ) );
-        exit(1);
+        $self->failed(1);
     }
 
 }
@@ -739,6 +812,8 @@ sub get_assoc {
                 )
             );
         }
+
+        $dbh->disconnect;
     }
 }
 
@@ -780,14 +855,14 @@ sub check_assoc {
     my @no = ( keys %p );
     if (@no) {
         $self->trace( "[E] Uncorrect association: " . join( ',', @no ) );
-        exit(1);
+        $self->failed(1);
     }
 
 }
 
 sub annote {
     my ($self) = @_;
-    return if ( $self->{blind} || !$self->{annote} );
+    return if ( !$self->{annote} );
 
     my $nf = $self->{temp_dir} . "/num-pdf";
     open( NUMS, ">$nf" );
@@ -813,6 +888,13 @@ sub annote {
         '--darkness-threshold-up', $self->{seuil_up},
     );
     push @args, '--names-file', '%PROJ/' . $self->{list} if ( $self->{list} );
+
+    my $single_output = '';
+    if ( $self->{annotate_single} ) {
+        $single_output = $self->{annotate_single}->{filename} || "all.pdf";
+        push @args, '--single-output', $single_output;
+    }
+
     $self->amc_command( 'annotate', @args );
 
     my $pdf_dir = $self->{temp_dir} . '/cr/corrections/pdf';
@@ -820,14 +902,44 @@ sub annote {
       || die "can't opendir $pdf_dir: $!";
     my @pdf = grep { /\.pdf$/i } readdir($dh);
     closedir $dh;
-    for my $f (@pdf) { $self->see_file( $pdf_dir . '/' . $f ); }
+    if ( !$self->{blind} ) {
+        for my $f (@pdf) { $self->see_file( $pdf_dir . '/' . $f ); }
+    }
+
+    if ($single_output) {
+        if ( $self->{annotate_single}->{npages} ) {
+            if (
+                open( INFO, "-|",
+                    "pdfinfo", $pdf_dir . '/' . $single_output
+                )
+              )
+            {
+                my $np = 0;
+                while (<INFO>) {
+                    $np = $1 if (/^Pages:\s*([0-9]+)/);
+                }
+                close INFO;
+                if ( $np == $self->{annotate_single}->{npages} ) {
+                    $self->trace("[T] Single annotated PDF: $np pages");
+                } else {
+                    $self->trace(
+"[E] Wrong number of pages for single annotated PDF: $np instead of "
+                          . $self->{annotate_single}->{npages} );
+                    $self->failed(1);
+                }
+            } else {
+                $self->trace("[E] pdfinfo failed: $!");
+                $self->failed(1);
+            }
+        }
+    }
 
     if ( @{ $self->{annote_files} } ) {
         my %p = map { $_ => 1 } @pdf;
         for my $f ( @{ $self->{annote_files} } ) {
             if ( !$p{$f} ) {
                 $self->trace("[E] Annotated file $f has not been generated.");
-                exit(1);
+                $self->failed(1);
             }
         }
         $self->trace( "[T] Annotated file names: "
@@ -837,17 +949,27 @@ sub annote {
 
 sub ok {
     my ($self) = @_;
+
     $self->end;
-    if ( @{ $self->{to_check} } ) {
-        $self->trace( "[?] "
-              . ( 1 + $#{ $self->{to_check} } )
-              . " files to check in $self->{check_dir}:" );
-        for ( @{ $self->{to_check} } ) {
-            $self->trace( "    " . $_->[0] . " " . $_->[1] );
-        }
-        exit(2) if ( !$self->{blind} );
+
+    if($self->{additional_test}) {
+        &{ $self->{additional_test} }($self);
+    }
+
+    if ( $self->{error} ) {
+        $self->trace("[E] Test failed (see errors above)");
     } else {
-        $self->trace("[0] Test completed succesfully");
+        if ( @{ $self->{to_check} } ) {
+            $self->trace( "[?] "
+                  . ( 1 + $#{ $self->{to_check} } )
+                  . " files to check in $self->{check_dir}:" );
+            for ( @{ $self->{to_check} } ) {
+                $self->trace( "    " . $_->[0] . " " . $_->[1] );
+            }
+            $self->failed(2) if ( !$self->{blind} );
+        } else {
+            $self->trace("[0] Test completed succesfully");
+        }
     }
 }
 
@@ -858,6 +980,9 @@ sub get_defects {
     $l->begin_read_transaction('test');
     my $d = { $l->defects() };
     $l->end_transaction('test');
+
+    $l->disconnect;
+
     return ($d);
 }
 
@@ -869,7 +994,7 @@ sub defects {
     my @t = ( keys %$d );
     if (@t) {
         $self->trace( "[E] Layout defects: " . join( ', ', @t ) );
-        exit 1;
+        $self->failed(1);
     } else {
         $self->trace("[T] No layout defects");
     }
@@ -886,6 +1011,7 @@ sub check_export {
             '--association-key', $self->{list_key},
             '--option-out',      'columns=' . $self->{export_columns},
             '--option-out',      'ticked=' . $self->{export_csv_ticked},
+            '--option-out',      'decimal=' . $self->{export_csv_decimal},
             '-o',                '%PROJ/export.csv',
         );
         push @args, '--fich-noms', '%PROJ/' . $self->{list}
@@ -901,11 +1027,13 @@ sub check_export {
         if ( !defined($copy) && !defined($name) ) {
             $self->trace( "[E] CSV: "
                   . translate_column_title('copie') . ' or '
-                  . translate_column_title('name')
+                  . translate_column_title('nom')
                   . " columns not found" );
-            exit(1);
+            $self->failed(1);
         }
+        my $irow = 0;
         while ( my $row = $c->getline($fh) ) {
+            $irow++;
             for my $t (@csv) {
                 my $goodrow = '';
                 if ( $t->{-copy} && $t->{-copy} eq $row->[$copy] ) {
@@ -914,6 +1042,9 @@ sub check_export {
                 if ( $t->{-name} && $t->{-name} eq $row->[$name] ) {
                     $goodrow = 'name ' . $t->{-name};
                 }
+                if ( $t->{-irow} && $t->{-irow} == $irow ) {
+                    $goodrow = 'irow ' . $t->{-irow};
+                }
                 if (   $goodrow
                     && $t->{-question}
                     && defined( $heads{ $t->{-question} } )
@@ -934,6 +1065,13 @@ sub check_export {
                         "score for $goodrow Q=" . $t->{-question} );
                     $t->{checked} = 1;
                 }
+                if (   $goodrow
+                    && $t->{-aname} )
+                {
+                    $self->test( $row->[ $name ],
+                        $t->{-aname}, "name for $goodrow" );
+                    $t->{checked} = 1;
+                }
             }
         }
         close $fh;
@@ -942,7 +1080,7 @@ sub check_export {
                 $self->trace( "[E] CSV: line not found. "
                       . join( ', ', map { $_ . '=' . $t->{$_} } ( keys %$t ) )
                 );
-                exit(1);
+                $self->failed(1);
             }
         }
         $self->end;
@@ -988,7 +1126,7 @@ sub check_export {
             } else {
                 $self->trace(
                     "[E] Stats: question not found in stats table: $q->{id}");
-                exit 1;
+                $self->failed(1);
             }
         }
         $self->end;
@@ -1046,12 +1184,12 @@ sub check_zooms {
                   . ( 1 + $#zooms )
                   . " elements, but needs "
                   . $cz->{$p} );
-            exit(1);
+            $self->failed(1);
         }
     }
 
     $capture->end_transaction('cZOO');
-
+    $capture->disconnect;
 }
 
 sub check_textest {
@@ -1072,7 +1210,7 @@ sub check_textest {
         while (<TEX>) {
             if (/^\!/) {
                 $self->trace("[E] latex error: $_");
-                exit(1);
+                $self->failed(1);
             }
             if (/^SECTION\((.*)\)/) {
                 $self->end();
@@ -1098,7 +1236,7 @@ sub check_textest {
         $self->end();
     } else {
         $self->trace("[X] TeX file not found: $tex_file");
-        exit(1);
+        $self->failed(1);
     }
   }
 
@@ -1158,7 +1296,7 @@ sub test {
                   . $self->{test_title}
                   . " [$subtest] : \'$x\' should be \'$v\'" );
             $self->datadump;
-            exit(1);
+            $self->failed(1);
         }
     }
 }
@@ -1171,7 +1309,7 @@ sub test_undef {
               . $self->{test_title}
               . " [$self->{'n.subt'}] : \'$x\' should be undef" );
         $self->datadump;
-        exit(1);
+        $self->failed(1);
     }
 }
 
@@ -1222,6 +1360,8 @@ sub test_scoring {
     set_debug('');
 
     $self->test( $score, $target_score );
+
+    $data->disconnect;
 }
 
 sub update_sqlite {
@@ -1248,6 +1388,7 @@ sub check_pages {
             $self->test( $mx, $self->{pages}->[$i] );
         }
         $l->end_transaction('npag');
+        $l->disconnect;
     }
 }
 
