@@ -1,7 +1,7 @@
 
 import os
 import os.path
-from shutil import copyfile, rmtree
+from shutil import copyfile, copytree, rmtree
 import csv
 import subprocess
 import time
@@ -62,7 +62,7 @@ class AMC:
         self.cups_pdf_dir = os.getenv("HOME") + '/PDF'
         self.tmp_bookmark = 'AMC-tmp'
         self.project_name = 'test'
-        self.debug = False
+        self.debug = (os.getenv("AMC_DEBUG") == '1')
         self.src_dirname = 'sources'
         self.print_subdir = 'printed_copies'
         self.config_file = 'cf.xml'
@@ -70,6 +70,7 @@ class AMC:
         self.global_password = 'ABCDEF'
         self.password_column = 'id'
         self.amc_path = os.getenv("AMC_PATH")
+        self.delimiter = ';'
         if not self.amc_path:
             self.amc_path = 'auto-multiple-choice'
 
@@ -85,15 +86,24 @@ class AMC:
         else:
             return self.project_name
 
+    def template_file(self, name):
+        return os.getenv("HOME") + '/.AMC.d/Models/' + name + '.tgz'
+
     def project_dir(self):
         return self.tmp_dir + '/' + self.project_name
 
+    def printed_dir(self):
+        return self.project_dir() + '/' + self.print_subdir
+
     def src_dir(self):
         return self.tmp_dir + '/' + self.src_dirname
 
-    def copy_in_src_dir(self, path):
+    def check_src_dir(self):
         if not os.path.isdir(self.src_dir()):
             os.mkdir(self.src_dir())
+
+    def copy_in_src_dir(self, path):
+        self.check_src_dir()
         base = os.path.basename(path)
         copyfile(path, self.src_dir() + '/' + base)
         return base
@@ -108,15 +118,29 @@ class AMC:
         dialog.grab_focus()
         dialog.child(button).click()
 
-    def launch(self):
-        if os.path.exists(self.src_dir()):
+    def find_description(self, d):
+        return self.gui.findChildren(
+            dogtail.predicate.GenericPredicate(
+                description=d))[0]
+
+    def find_along_with(self, name, with_name):
+        for i in self.gui.findChildren(
+                dogtail.predicate.GenericPredicate(
+                    name=name)):
+            if i.parent.findChildren(
+                dogtail.predicate.GenericPredicate(
+                    name=with_name)):
+                return i
+
+    def launch(self, delete_sources=True):
+        if delete_sources and os.path.exists(self.src_dir()):
             rmtree(self.src_dir())
         copyfile(self.config_file, os.getenv("HOME")
                  + '/.AMC.d/cf.TEST.xml')
         os.environ["LANG"] = "en_US.UTF-8"
         dogtail.utils.run(self.amc_cmd(), timeout=3,
                           appName='auto-multiple-choice')
-        self.gui = root.application('AMC-gui.pl')
+        self.gui = root.application('auto-multiple-choice')
         self.gui.grab_focus()
         if self.debug:
             self.click_dialog()
@@ -210,7 +234,7 @@ class AMC:
         return (table, scrollbar, 1)
 
     def select_in_current_dir(self, filename,
-                              buttonName='Apply',
+                              buttonName='Apply', buttonDescription='',
                               double=False, enter=False,
                               hold_control=False):
         self.scroll_and_click(self.chooser_files_table(),
@@ -218,9 +242,13 @@ class AMC:
                               double=double, enter=enter,
                               hold_control=hold_control)
         chooser = self.file_chooser_or_dialog()
-        if buttonName != '':
+
+        if buttonDescription != '':
             time.sleep(0.5)
-            chooser.child(buttonName).click()
+            chooser.child(description=buttonDescription).click()
+        elif buttonName != '':
+            time.sleep(0.5)
+            chooser.child(name=buttonName).click()
         return chooser
 
     def select_multiple_in_src_dir(self, files, buttonName='OK'):
@@ -245,6 +273,57 @@ class AMC:
     def tab(self, tabname):
         return self.gui.child(tabname, roleName='page tab')
 
+    def open_project(self, name, source_dir):
+        self.project_name = name
+        # First remove project if already existing
+        if os.path.isdir(self.project_dir()):
+            rmtree(self.project_dir())
+        # Copy files to project directory
+        copytree(source_dir, self.project_dir())
+        # Go to AMC window and click 'Open'
+        self.gui.grab_focus()
+        self.gui.child('Open').click()
+        # Choose project
+        dialog = self.gui.child('Open a MC project')
+        dialog.grab_focus()
+        dialog.child(name).click()
+        dialog.child('Open').click()
+
+    def create_template(self, name, with_files=None):
+        t = self.template_file(name)
+        if os.path.exists(t):
+            os.remove(t)
+        self.gui.grab_focus()
+        self.find_description('Menu').click()
+        time.sleep(1)
+        self.find_along_with('Project', 'Plugins').click()
+        time.sleep(1)
+        self.gui.child('Export as template', roleName='push button').click()
+        time.sleep(1)
+        # Fill dialog
+        dialog = self.gui.child('Save as a template')
+        entry = sorted([(a.position[1], a.position[0], a)
+                        for a in dialog.findChildren(
+                                dogtail.predicate.GenericPredicate(
+                                    roleName='text'))])
+        entry[0][2].text = name
+        entry[1][2].text = 'Template ' + name
+        entry[2][2].text = 'This is a test template named '+ name
+        time.sleep(1)
+        
+        if with_files is not None:
+            dialog.child('Add').click()
+            time.sleep(1)
+            file_dialog = self.gui.child('Add files to template')
+            for f in with_files:
+                file_dialog.child(f).click()
+                time.sleep(1)
+            file_dialog.child(name='Add', roleName='push button').click()
+            time.sleep(1)
+
+        dialog.child('OK').click()
+        time.sleep(2)
+
     def new_project_base(self):
         # First remove project if already existing
         if os.path.isdir(self.project_dir()):
@@ -284,8 +363,9 @@ class AMC:
         self.new_project_base()
         self.new_project_mode('Template')
         dialog = self.gui.child('Template selection')
-        endoc = dialog.child(section)
-        endoc.actions['expand or contract'].do()
+        if section is not None:
+            endoc = dialog.child(section)
+            endoc.actions['expand or contract'].do()
         dialog.child(template).click()
         dialog.child('Apply').click()
 
@@ -413,12 +493,22 @@ class AMC:
         # few sheets to print -> photocopy mode = No
         self.click_dialog(button="No")
 
+    def check_printed(self, files=[]):
+        d = self.printed_dir() + '/'
+        for f in files:
+            if os.path.getsize(d+f) >= 100:
+                print("Printed file %s: size=%d" % (f, os.path.getsize(d+f)))
+            else:
+                raise Exception("Can't find printed file %s" % f)
+
     def scan_from_blank_copy(self, student=2, dest='scan-blank-2.jpg'):
+        self.check_src_dir()
         os.system("convert -density 300 \"%s/%s/sheet-%04d.pdf\" \"%s/%s\""
                   % (self.project_dir(), self.print_subdir, student,
                      self.src_dir(), dest))
 
     def scan_from_individual_solution(self, pages=[3], dest='scan-sol-3.pdf'):
+        self.check_src_dir()
         p = " ".join([str(x) for x in pages])
         os.system(("qpdf \"%s/DOC-indiv-solution.pdf\"" +
                    " --pages \"%s/DOC-indiv-solution.pdf\" %s" +
@@ -568,7 +658,7 @@ class AMC:
         marking = self.tab('Marking')
         marking.select()
         marking.child('Set file', roleName='push button').click()
-        self.select_in_current_dir(students_file)
+        self.select_in_current_dir(students_file, buttonDescription='Apply')
         # select uid/code for association
         cbs = sorted([(a.position[1], a)
                       for a in marking.findChildren(
@@ -597,6 +687,10 @@ class AMC:
         """Build the report, where output_format can be 'OpenOffice',
         'CSV', 'PDF list' (or other if plugins are installed)."""
 
+        if output_format=='CSV':
+            # select delimiter
+            options_cb.append((0,self.delimiter))
+        
         reports = self.gui.child('Reports', roleName='page tab')
         reports.select()
         export_button = reports.child('Export', roleName='push button')
@@ -628,12 +722,13 @@ class AMC:
                     cbx[o[0]][1].combovalue = o[1]
         # go
         export_button.click()
+        time.sleep(2)
 
     def check_csv_results(self, checks):
         errors = 0
         with open(self.project_dir() + "/exports/" +
                   self.code() + '.csv') as csv_file:
-            csv_reader = csv.DictReader(csv_file, delimiter=';')
+            csv_reader = csv.DictReader(csv_file, delimiter=self.delimiter)
             for row in csv_reader:
                 e = row["Exam"]
                 if e in checks:
@@ -659,7 +754,7 @@ class AMC:
                               + '/cr/corrections/pdf/' + f):
                 print("[Annotated] OK %s" % f)
             else:
-                print("[Annotated] MISSING %s" % f)
+                print("[Annotated] MISSING %s in %s" % (f, self.project_dir()))
                 errors += 1
         if errors > 0:
             raise ValueError("Some annotated answer sheets are missing.")
@@ -670,6 +765,7 @@ class AMC:
         annotated = reports.child('Annotated papers', roleName='panel')
         annotated.child(roleName='text').text = model
         reports.child('Annotate papers', roleName='push button').click()
+        time.sleep(4)
 
     def set_options(self,
                     description=['TEST EXAM', 'test'],
@@ -707,8 +803,21 @@ class AMC:
         dialog.child('OK').click()
         time.sleep(2)
 
-    def finished(self):
+    def quit(self):
         self.gui.child('Close').click()
+        time.sleep(1)
+
+    def screenshot(self, name):
+        print("Screenshot " + name)
+        f = "%s/screenshot-%s.jpg" % (self.project_dir(), name)
+        try:
+            # works only with X
+            os.system("import", "window", "root", f)
+        except:
+            print("Screenshot failed")
+
+    def finished(self):
+        self.quit()
         print("")
         print("********************")
         print("*     SUCCESS!     *")
