@@ -1,6 +1,6 @@
-#! /usr/bin/perl
+#! /usr/bin/env perl
 #
-# Copyright (C) 2018-2021 Alexis Bienvenüe <paamc@passoire.fr>
+# Copyright (C) 2018-2022 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -40,7 +40,7 @@ delete( $d->{DIFFERENT_POSITIONS} );
 
 my @t = ( keys %$d );
 if (@t) {
-    $self->trace( "[E] Layout defects: " . join( ', ', @t ) );
+    $t->trace( "[E] Layout defects: " . join( ', ', @t ) );
 }
 
 $t->ok;
