@@ -1,6 +1,6 @@
-#! /usr/bin/perl
+#! /usr/bin/env perl
 #
-# Copyright (C) 2014-2017 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2014-2022 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,7 +20,10 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,'tex_engine'=>'pdflatex',
-	       notemax=>0,check_marks=>{3=>15})
-  ->default_process;
+AMC::Test->new(
+    dir         => __FILE__,
+    tex_engine  => 'pdflatex',
+    notemax     => 0,
+    check_marks => { 3 => 15 }
+)->default_process;
 
