@@ -1,6 +1,6 @@
-#! /usr/bin/perl
+#! /usr/bin/env perl
 #
-# Copyright (C) 2016-2017 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2016-2022 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,7 +20,8 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,
-               export_full_csv=>[{-copy=>3,-question=>'add',-score=>2}])
-  ->default_process;
+AMC::Test->new(
+    dir             => __FILE__,
+    export_full_csv => [ { -copy => 3, -question => 'add', -score => 2 } ]
+)->default_process;
 
