@@ -1,6 +1,6 @@
-#! /usr/bin/perl
+#! /usr/bin/env perl
 #
-# Copyright (C) 2018 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2018-2022 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,8 +20,12 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,'filter'=>'plain','tex_engine'=>'xelatex',
-               force_convert=>1,notemax=>0,
-               check_marks=>{2=>11,4=>12},
-	      )->default_process;
+AMC::Test->new(
+    dir           => __FILE__,
+    filter        => 'plain',
+    tex_engine    => 'xelatex',
+    force_convert => 1,
+    notemax       => 0,
+    check_marks   => { 2 => 11, 4 => 12 },
+)->default_process;
 
