@@ -1,6 +1,6 @@
-#! /usr/bin/perl
+#! /usr/bin/env perl
 #
-# Copyright (C) 2018 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2018-2022 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,6 +20,9 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,'n_copies'=>0,
-	       'tex_engine'=>'pdflatex',extract_with=>'qpdf')
-  ->default_process;
+AMC::Test->new(
+    dir          => __FILE__,
+    n_copies     => 0,
+    tex_engine   => 'pdflatex',
+    extract_with => 'qpdf'
+)->default_process;
