@@ -1,6 +1,6 @@
-#! /usr/bin/perl
+#! /usr/bin/env perl
 #
-# Copyright (C) 2018 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2018-2022 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,5 +20,8 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,'tex_engine'=>'xelatex',extract_with=>'pdftk+NA')
-  ->default_process;
+AMC::Test->new(
+    dir          => __FILE__,
+    tex_engine   => 'xelatex',
+    extract_with => 'pdftk+NA'
+)->default_process;
