@@ -1,6 +1,6 @@
-#! /usr/bin/perl
+#! /usr/bin/env perl
 #
-# Copyright (C) 2012-2017 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2012-2022 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,12 +20,15 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,'filter'=>'plain','tex_engine'=>'xelatex',
-	       'export_full_csv'=>[
-				  {-copy=>3,-question=>'deuxdeux',-score=>1},
-				  {-copy=>3,-question=>'fusion',-score=>2},
-				  {-copy=>3,-question=>'france',-score=>3},
-				  {-copy=>3,-question=>'oceans',-score=>4},
-				  ],
-	      )->default_process;
+AMC::Test->new(
+    dir             => __FILE__,
+    filter          => 'plain',
+    tex_engine      => 'xelatex',
+    export_full_csv => [
+        { -copy => 3, -question => 'deuxdeux', -score => 1 },
+        { -copy => 3, -question => 'fusion',   -score => 2 },
+        { -copy => 3, -question => 'france',   -score => 3 },
+        { -copy => 3, -question => 'oceans',   -score => 4 },
+    ],
+)->default_process;
 
