@@ -1,6 +1,6 @@
-#! /usr/bin/perl
+#! /usr/bin/env perl
 #
-# Copyright (C) 2012-2017 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2012-2022 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,14 +20,18 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,
-	       'tex_engine'=>'pdflatex',
-	       'perfect_copy'=>'','seuil'=>0.15,
-	       'postcorrect_student'=>2,'postcorrect_copy'=>0,
-	       'check_marks'=>{2=>20,3=>12.5},
-	       'check_assoc'=>{2=>'01012012',3=>'01234567'},
-	       'model'=>'(team)',
-	       'annote'=>[3],'annote_files'=>['Tas_d_oeufs_casses.pdf'],'annote_ascii'=>1,
-	      )
-  ->default_process;
+AMC::Test->new(
+    dir                 => __FILE__,
+    tex_engine          => 'pdflatex',
+    perfect_copy        => '',
+    seuil               => 0.15,
+    postcorrect_student => 2,
+    postcorrect_copy    => 0,
+    check_marks         => { 2 => 20, 3 => 12.5 },
+    check_assoc         => { 2 => '01012012', 3 => '01234567' },
+    model               => '(team)',
+    annote              => [3],
+    annote_files        => ['Tas_d_oeufs_casses.pdf'],
+    annote_ascii        => 1,
+)->default_process;
 
