@@ -1,6 +1,6 @@
-#! /usr/bin/perl
+#! /usr/bin/env perl
 #
-# Copyright (C) 2016-2017 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2016-2022 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -23,7 +23,7 @@ use AMC::Basic;
 
 use_gettext;
 
-my $t=AMC::Test->new('dir'=>__FILE__);
+my $t = AMC::Test->new( dir => __FILE__ );
 
 $t->check_textest();
 
