@@ -1,7 +1,8 @@
 
 try_one() {
   t=$1
-  if $t --to-stdout $ARGS $@ > $RESULT_FILE
+  echo -en "[....] $t\r"
+  if $t --to-stdout $ARGS > $RESULT_FILE
   then
       if grep -iq 'uninitialized' $RESULT_FILE ;
       then
